<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh">
<context>
    <name>BitcoinButton</name>
    <message>
        <location filename="../BitcoinButton.qml" line="34"/>
        <source>Bitcoin address</source>
        <translation>Bitcoin地址</translation>
    </message>
    <message>
        <location filename="../BitcoinButton.qml" line="111"/>
        <source>Copy address</source>
        <translation>复制地址</translation>
    </message>
    <message>
        <location filename="../BitcoinButton.qml" line="116"/>
        <source>Bitcoin address copied to clipboard</source>
        <translation>Bitcoin 地址已经复制到剪切板</translation>
    </message>
</context>
<context>
    <name>DonationDialog</name>
    <message>
        <location filename="../DonationDialog.qml" line="8"/>
        <source>Choose a donation method:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FileSelector</name>
    <message>
        <location filename="../FileSelector.qml" line="14"/>
        <source>File Selector</source>
        <translation>文件选择</translation>
    </message>
</context>
<context>
    <name>FlattrButton</name>
    <message>
        <location filename="../FlattrButton.qml" line="25"/>
        <source>Opening &lt;b&gt;Flattr&lt;/b&gt; donation page, &lt;b&gt;thanks&lt;/b&gt;!</source>
        <translation>打开 &lt;b&gt;Flattr&lt;/b&gt; 捐赠页面 &lt;b&gt;谢谢&lt;/b&gt;！</translation>
    </message>
</context>
<context>
    <name>HistoryPage</name>
    <message>
        <location filename="../HistoryPage.qml" line="20"/>
        <source>Delete</source>
        <translation>删除</translation>
    </message>
    <message>
        <location filename="../HistoryPage.qml" line="31"/>
        <location filename="../HistoryPage.qml" line="118"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <location filename="../HistoryPage.qml" line="54"/>
        <source>Do not delete items</source>
        <translation>确定删除这些条目</translation>
    </message>
    <message>
        <location filename="../HistoryPage.qml" line="54"/>
        <source>Delete items</source>
        <translation>删除记录</translation>
    </message>
    <message>
        <location filename="../HistoryPage.qml" line="57"/>
        <source>Select items to delete</source>
        <translation>选择要删除的条目</translation>
    </message>
    <message>
        <location filename="../HistoryPage.qml" line="61"/>
        <location filename="../HistoryPage.qml" line="115"/>
        <source>Erase history</source>
        <translation>清空记录</translation>
    </message>
    <message>
        <location filename="../HistoryPage.qml" line="74"/>
        <source>no entries</source>
        <translation>不清空</translation>
    </message>
    <message>
        <location filename="../HistoryPage.qml" line="116"/>
        <source>Do you want to erase the history of all mangas and comic books opened by Mieru?</source>
        <translation>你确定要清空所有 Mieru 打开的漫画及Manga的阅读记录？</translation>
    </message>
    <message>
        <location filename="../HistoryPage.qml" line="117"/>
        <source>Erase</source>
        <translation>清空</translation>
    </message>
</context>
<context>
    <name>InfoPage</name>
    <message>
        <location filename="../InfoPage.qml" line="14"/>
        <source>Info</source>
        <translation>信息</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="18"/>
        <source>Stats</source>
        <translation>状态</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="22"/>
        <source>About</source>
        <translation>关于</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="77"/>
        <source>Properties</source>
        <translation>属性</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="80"/>
        <source>Pages</source>
        <translation>页数</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="83"/>
        <source>Path</source>
        <translation>路径</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="91"/>
        <source>Online search</source>
        <translation>在线搜索</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="97"/>
        <source>Opening &lt;b&gt;Google&lt;/b&gt; search</source>
        <translation>打开&lt;b&gt;Google&lt;/b&gt;进行搜索</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="106"/>
        <source>Opening &lt;b&gt;Wikipedia&lt;/b&gt; search</source>
        <translation>打开&lt;b&gt;Wikipedii&lt;/b&gt;进行搜索</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="115"/>
        <source>Opening &lt;b&gt;Manga updates&lt;/b&gt; search</source>
        <translation>打开&lt;b&gt;Manga&lt;/b&gt;检查更新</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="132"/>
        <source>Usage Statistics</source>
        <translation>使用统计</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="162"/>
        <location filename="../InfoPage.qml" line="271"/>
        <source>Reset</source>
        <translation>重置</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="207"/>
        <source>Mieru is a flexible Manga and comic book reader.</source>
        <translation>Mieru是一款优秀的漫画阅读软件。</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="243"/>
        <source>main developer</source>
        <translation>主开发者</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="246"/>
        <source>email</source>
        <translation>邮箱</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="250"/>
        <source>www</source>
        <translation>网址</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="255"/>
        <source>discussion</source>
        <translation>讨论</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="269"/>
        <source>Reset all usage statistics</source>
        <translation>清空统计记录</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="270"/>
        <source>Do you really want to reset all usage statistics?</source>
        <translation>你确定要删除所有的使用统计记录么？</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="272"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
</context>
<context>
    <name>MainView</name>
    <message>
        <location filename="../MainView.qml" line="169"/>
        <source>original</source>
        <translation>1:1显示</translation>
    </message>
    <message>
        <location filename="../MainView.qml" line="171"/>
        <source>width</source>
        <translation>适应宽度</translation>
    </message>
    <message>
        <location filename="../MainView.qml" line="173"/>
        <source>height</source>
        <translation>适应高度</translation>
    </message>
    <message>
        <location filename="../MainView.qml" line="175"/>
        <source>screen</source>
        <translation>适应屏幕</translation>
    </message>
    <message>
        <location filename="../MainView.qml" line="177"/>
        <source>orient</source>
        <translation>定位显示</translation>
    </message>
    <message>
        <location filename="../MainView.qml" line="184"/>
        <source>most</source>
        <translation>最大显示</translation>
    </message>
    <message>
        <location filename="../MainView.qml" line="192"/>
        <source>custom</source>
        <translation>自定义</translation>
    </message>
    <message>
        <location filename="../MainView.qml" line="250"/>
        <source>Open file</source>
        <translation>打开文件</translation>
    </message>
    <message>
        <location filename="../MainView.qml" line="257"/>
        <source>History</source>
        <translation>历史记录</translation>
    </message>
    <message>
        <location filename="../MainView.qml" line="261"/>
        <source>Info</source>
        <translation>信息</translation>
    </message>
    <message>
        <location filename="../MainView.qml" line="265"/>
        <source>Options</source>
        <translation>选项</translation>
    </message>
    <message>
        <location filename="../MainView.qml" line="272"/>
        <source>Quit</source>
        <translation>退出</translation>
    </message>
    <message>
        <location filename="../MainView.qml" line="504"/>
        <source>Rotation</source>
        <translation>旋转</translation>
    </message>
    <message>
        <location filename="../MainView.qml" line="524"/>
        <source>No pages loaded</source>
        <translation>没有可载入页面了</translation>
    </message>
</context>
<context>
    <name>OptionsPage</name>
    <message>
        <location filename="../OptionsPage.qml" line="29"/>
        <source>Page view</source>
        <translation>页面显示</translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="32"/>
        <source>Rotation</source>
        <translation>旋转</translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="47"/>
        <source>auto</source>
        <translation>自动</translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="55"/>
        <source>portrait</source>
        <translation>竖屏</translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="63"/>
        <source>landscape</source>
        <translation>横屏</translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="71"/>
        <source>Show status bar</source>
        <translation>显示状态栏</translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="79"/>
        <source>Remember toolbar state</source>
        <translation>记住工具条状态</translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="86"/>
        <source>Fullscreen button opacity</source>
        <translation>全屏时按键不透明度</translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="112"/>
        <source>Paging options</source>
        <translation>翻页设置</translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="115"/>
        <source>Paging mode</source>
        <translation>翻页模式</translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="130"/>
        <source>Whole screen</source>
        <translation>整个屏幕</translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="138"/>
        <source>On edges</source>
        <translation>边缘部分</translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="148"/>
        <source>Middle click</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="158"/>
        <source>Middle doubleclick</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="168"/>
        <source>Show paging feedback</source>
        <translation>显示翻页反馈</translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="178"/>
        <source>Page scaling</source>
        <translation>页面缩放</translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="181"/>
        <source>Page fit mode</source>
        <translation>页面适应设置</translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="190"/>
        <source>History</source>
        <translation type="unfinished">历史记录</translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="193"/>
        <source>history enabled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="201"/>
        <source>use when opening files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="210"/>
        <source>Miscellaneous</source>
        <translation>杂项</translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="213"/>
        <source>Manga reading mode</source>
        <translation>Manga阅读模式</translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="221"/>
        <source>Show release notes</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PageFitSelector</name>
    <message>
        <location filename="../PageFitSelector.qml" line="10"/>
        <source>Page fit mode</source>
        <translation>页面适应模式</translation>
    </message>
    <message>
        <location filename="../PageFitSelector.qml" line="19"/>
        <source>&lt;b&gt;1:1&lt;/b&gt; - original size</source>
        <translation>&lt;b&gt;1:1&lt;/b&gt; - 页面原大小</translation>
    </message>
    <message>
        <location filename="../PageFitSelector.qml" line="20"/>
        <source>&lt;b&gt;fit to width&lt;/b&gt;</source>
        <translation>&lt;b&gt;适应屏幕宽度&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../PageFitSelector.qml" line="21"/>
        <source>&lt;b&gt;fit to height&lt;/b&gt;</source>
        <translation>&lt;b&gt;适应屏幕高度&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../PageFitSelector.qml" line="22"/>
        <source>&lt;b&gt;fit to screen&lt;/b&gt;</source>
        <translation>&lt;b&gt;适应屏幕&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../PageFitSelector.qml" line="23"/>
        <source>&lt;b&gt;custom&lt;/b&gt; - remember scale</source>
        <translation>&lt;b&gt;自定义&lt;/b&gt; - 记住缩放比</translation>
    </message>
    <message>
        <location filename="../PageFitSelector.qml" line="24"/>
        <source>&lt;b&gt;orientation&lt;/b&gt; specific</source>
        <translation>&lt;b&gt;特定位置&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../PageFitSelector.qml" line="25"/>
        <source>&lt;b&gt;show the most&lt;/b&gt;</source>
        <translation>&lt;b&gt;尽量显示&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../PageFitSelector.qml" line="30"/>
        <source>&lt;b&gt;no action&lt;/b&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PayPalButton</name>
    <message>
        <location filename="../PayPalButton.qml" line="24"/>
        <source>Opening &lt;b&gt;PayPal&lt;/b&gt; donation page, &lt;b&gt;thanks&lt;/b&gt;!</source>
        <translation>打开&lt;b&gt;PayPal&lt;/b&gt;捐赠页面 &lt;b&gt;谢谢&lt;/b&gt;！</translation>
    </message>
</context>
<context>
    <name>WhatsNewDialog</name>
    <message>
        <location filename="../WhatsNewDialog.qml" line="35"/>
        <source>Opening link</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../WhatsNewDialog.qml" line="48"/>
        <source>&lt;b&gt;Do you like Mieru ? Donate !&lt;/b&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../WhatsNewDialog.qml" line="56"/>
        <source>How to donate ?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../WhatsNewDialog.qml" line="67"/>
        <source>Don&apos;t show again</source>
        <translation>不再显示</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../main.qml" line="96"/>
        <source>How to turn pages</source>
        <translation>怎样进行翻页</translation>
    </message>
    <message>
        <location filename="../main.qml" line="97"/>
        <source>Tap the &lt;b&gt;right half&lt;/b&gt; of the screen to go to the &lt;b&gt;next page&lt;/b&gt;.</source>
        <translation>点击&lt;b&gt;右半部屏幕&lt;/b&gt;翻到&lt;b&gt;下一页&lt;/b&gt;。</translation>
    </message>
    <message>
        <location filename="../main.qml" line="98"/>
        <source>Tap the &lt;b&gt;left half&lt;/b&gt; to go to the &lt;b&gt;previous page&lt;/b&gt;.</source>
        <translation>点击&lt;b&gt;左半部屏幕&lt;/b&gt;翻到&lt;b&gt;上一页&lt;/b&gt;。</translation>
    </message>
    <message>
        <location filename="../main.qml" line="99"/>
        <source>Don&apos;t show again</source>
        <translation>不再显示</translation>
    </message>
    <message>
        <location filename="../main.qml" line="100"/>
        <source>OK</source>
        <translation>确定</translation>
    </message>
</context>
</TS>
